Elephant - Electrophysiology Analysis Toolkit — Elephant 0.5.0 documentation

# Elephant - Electrophysiology Analysis Toolkit

## Synopsis

Elephant is a toolbox for the analysis of electrophysiological data based on the Neo framework. This manual covers the installation of Elephant in an existing Python environment, several tutorials to help get you started, information on the structure and conventions of the library, a list of modules, and help for future contributors to Elephant.

## Table of Contents

- Overview
- Prerequisites / Installation
- Tutorials
- Function Reference by Module
- Developers’ guide
- Documentation and style guideline
- Authors and contributors
- Release Notes